@@ -14,10 +14,10 @@ from unittest.mock import patch
 from .formatters import DefaultHelpFormatter, empty_help, formatter_context, get_env_var
 from .jsonnet import ActionJsonnet
 from .jsonschema import ActionJsonSchema
-from .loaders_dumpers import check_valid_dump_format, dump_using_format, get_loader_exceptions, loaders, load_value, load_value_context
+from .loaders_dumpers import check_valid_dump_format, dump_using_format, get_loader_exceptions, loaders, load_value, load_value_context, yaml_load
 from .namespace import is_meta_key, Namespace, split_key, split_key_leaf, strip_meta
 from .signatures import is_pure_dataclass, SignatureArguments
-from .typehints import ActionTypeHint, LazyInitBaseClass
+from .typehints import ActionTypeHint
 from .actions import (
     ActionParser,
     ActionConfigFile,
@@ -35,13 +35,13 @@ from .actions import (
     parent_parsers,
 )
 from .optionals import (
-    argcomplete_support,
+    argcomplete_autocomplete,
+    argcomplete_namespace,
     fsspec_support,
-    omegaconf_support,
     get_config_read_mode,
-    import_jsonnet,
-    import_argcomplete,
     import_fsspec,
+    import_jsonnet,
+    omegaconf_support,
 )
 from .util import (
     identity,
@@ -50,9 +50,9 @@ from .util import (
     change_to_path_dir,
     Path,
     LoggerProperty,
-    _suppress_stderr,
     _lenient_check_context,
     lenient_check,
+    return_parser_if_captured,
 )
 
 
@@ -160,8 +160,9 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         version: Optional[str] = None,
         print_config: Optional[str] = '--print_config',
         parser_mode: str = 'yaml',
+        dump_header: Optional[List[str]] = None,
         default_config_files: Optional[List[str]] = None,
-        default_env: bool = False,
+        default_env: bool = yaml_load(os.environ.get('JSONARGPARSE_DEFAULT_ENV', 'False')),
         default_meta: bool = True,
         **kwargs
     ):
@@ -179,6 +180,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
             version: Program version string to add --version argument.
             print_config: Add this as argument to print config, set None to disable.
             parser_mode: Mode for parsing configuration files: ``'yaml'``, ``'jsonnet'`` or ones added via :func:`.set_loader`.
+            dump_header: Header to include as comment when dumping a config object.
             default_config_files: Default config file locations, e.g. :code:`['~/.config/myapp/*.yaml']`.
             default_env: Set the default value on whether to parse environment variables.
             default_meta: Set the default value on whether to include metadata in config objects.
@@ -193,6 +195,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         self.default_env = default_env
         self.env_prefix = env_prefix
         self.parser_mode = parser_mode
+        self.dump_header = dump_header
         self.logger = logger
         self.error_handler = error_handler
         self._print_config = print_config
@@ -217,9 +220,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         if namespace is None:
             namespace = Namespace()
 
-        if caller == 'argcomplete':
-            namespace.__class__ = Namespace
-            namespace = self.merge_config(self.get_defaults(skip_check=True), namespace).as_flat()
+        namespace = argcomplete_namespace(caller, self, namespace)
 
         try:
             with patch('argparse.Namespace', Namespace), _lenient_check_context(caller), ActionTypeHint.subclass_arg_context(self), load_value_context(self.parser_mode):
@@ -332,16 +333,13 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         Raises:
             ParserError: If there is a parsing error and error_handler=None.
         """
-        if argcomplete_support:
-            argcomplete = import_argcomplete('parse_args')
-            with load_value_context(self.parser_mode):
-                argcomplete.autocomplete(self)
+        return_parser_if_captured(self)
+        argcomplete_autocomplete(self)
 
         try:
-            with _suppress_stderr():
-                cfg, unk = self.parse_known_args(args=args)
-                if unk:
-                    self.error(f'Unrecognized arguments: {" ".join(unk)}')
+            cfg, unk = self.parse_known_args(args=args)
+            if unk:
+                self.error(f'Unrecognized arguments: {" ".join(unk)}')
 
             parsed_cfg = self._parse_common(
                 cfg=cfg,
@@ -827,8 +825,8 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
                     if action is None:
                         raise KeyError(f'No action for destination key "{dest}" to set its default.')
                     action.default = args[n][dest]
-                    if isinstance(action.default, LazyInitBaseClass):
-                        action.default = action.default.lazy_get_init_data()
+                    if isinstance(action, ActionTypeHint):
+                        action.normalize_default()
         if kwargs:
             self.set_defaults(kwargs)
 
@@ -1377,6 +1375,26 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
                 subparser.parser_mode = parser_mode  # type: ignore
 
 
+    @property
+    def dump_header(self) -> Optional[List[str]]:
+        """Header to include as comment when dumping a config object.
+
+        :getter: Returns the current dump header.
+        :setter: Sets the dump header.
+
+        Raises:
+            ValueError: If an invalid value is given.
+        """
+        return self._dump_header
+
+
+    @dump_header.setter
+    def dump_header(self, dump_header: Optional[List[str]]):
+        if not (dump_header is None or (isinstance(dump_header, list) and all(isinstance(x, str) for x in dump_header))):
+            raise ValueError('Expected dump_header to be None or a list of strings.')
+        self._dump_header = dump_header
+
+
 if omegaconf_support:
     from .loaders_dumpers import set_loader
     from .optionals import get_omegaconf_loader
