@@ -8,9 +8,9 @@ import stat
 import sys
 import warnings
 from collections import defaultdict
-from contextlib import contextmanager, redirect_stderr
+from contextlib import contextmanager
 from contextvars import ContextVar
-from typing import Any, Optional, Tuple, Union
+from typing import Any, Callable, Optional, Tuple, Union
 
 from .loaders_dumpers import load_value
 from .optionals import (
@@ -25,11 +25,12 @@ from .type_checking import ArgumentParser
 
 
 __all__ = [
-    'ParserError',
-    'null_logger',
-    'usage_and_exit_error_handler',
-    'Path',
+    'capture_parser',
     'LoggerProperty',
+    'null_logger',
+    'ParserError',
+    'Path',
+    'usage_and_exit_error_handler',
 ]
 
 
@@ -49,6 +50,10 @@ class ParserError(Exception):
     pass
 
 
+class DebugException(Exception):
+    pass
+
+
 class JsonargparseWarning(UserWarning):
     pass
 
@@ -61,6 +66,51 @@ def warning(message, category=JsonargparseWarning, stacklevel=1):
     )
 
 
+class CaptureParserException(Exception):
+    def __init__(self, parser: Optional[ArgumentParser]):
+        self.parser = parser
+        super().__init__('' if parser else 'No parse_args call to capture the parser.')
+
+
+parser_captured: ContextVar = ContextVar('parser_captured', default=False)
+
+
+@contextmanager
+def capture_parser_context():
+    t = parser_captured.set(True)
+    try:
+        yield
+    finally:
+        parser_captured.reset(t)
+
+
+def capture_parser(function: Callable, *args, **kwargs) -> ArgumentParser:
+    """Returns the parser object used within the execution of a function.
+
+    The function execution is stopped on the start of the call to parse_args. No
+    parsing is done or execution of instructions after the parse_args.
+
+    Args:
+        function: A callable that internally creates a parser and calls parse_args.
+        *args: Positional arguments used to run the function.
+        **kwargs: Keyword arguments used to run the function.
+
+    Raises:
+        CaptureParserException: If the function does not call parse_args.
+    """
+    try:
+        with capture_parser_context():
+            function(*args, **kwargs)
+    except CaptureParserException as ex:
+        return ex.parser
+    raise CaptureParserException(None)
+
+
+def return_parser_if_captured(parser: ArgumentParser):
+    if parser_captured.get():
+        raise CaptureParserException(parser)
+
+
 def identity(value):
     return value
 
@@ -68,7 +118,7 @@ def identity(value):
 def _parse_value_or_config(value: Any, enable_path: bool = True) -> Tuple[Any, Optional['Path']]:
     """Parses yaml/json config in a string or a path"""
     cfg_path = None
-    if enable_path and isinstance(value, str):
+    if enable_path and type(value) is str:
         try:
             cfg_path = Path(value, mode=get_config_read_mode())
         except TypeError:
@@ -76,9 +126,9 @@ def _parse_value_or_config(value: Any, enable_path: bool = True) -> Tuple[Any, O
         else:
             with change_to_path_dir(cfg_path):
                 value = load_value(cfg_path.get_content())
-    if isinstance(value, str) and value.strip() != '':
+    if type(value) is str and value.strip() != '':
         parsed_val = load_value(value)
-        if not isinstance(parsed_val, str):
+        if type(parsed_val) is not str:
             value = parsed_val
     if isinstance(value, dict) and cfg_path is not None:
         value['__path__'] = cfg_path
@@ -88,6 +138,9 @@ def _parse_value_or_config(value: Any, enable_path: bool = True) -> Tuple[Any, O
 def usage_and_exit_error_handler(parser: 'ArgumentParser', message: str) -> None:
     """Error handler that prints the usage and exits with error code 2 (same behavior as argparse).
 
+    If the JSONARGPARSE_DEBUG environment variable is set, instead of exit, a
+    DebugException is raised.
+
     Args:
         parser: The parser object.
         message: The message describing the error being handled.
@@ -95,7 +148,10 @@ def usage_and_exit_error_handler(parser: 'ArgumentParser', message: str) -> None
     parser.print_usage(sys.stderr)
     args = {'prog': parser.prog, 'message': message}
     sys.stderr.write('%(prog)s: error: %(message)s\n' % args)
-    parser.exit(2)
+    if 'JSONARGPARSE_DEBUG' in os.environ:
+        raise DebugException('jsonargparse debug enabled, thus raising exception instead of exit.')
+    else:
+        parser.exit(2)
 
 
 def _issubclass(cls, class_or_tuple):
@@ -120,6 +176,48 @@ def import_object(name: str):
     return getattr(parent, name_object)
 
 
+def import_module_leaf(name: str):
+    """Similar to __import__(name) but returns the leaf module instead of the root."""
+    if '.' in name:
+        name_parent, name_leaf = name.rsplit('.', 1)
+        parent = __import__(name_parent, fromlist=[name_leaf])
+        module = getattr(parent, name_leaf)
+    else:
+        module = __import__(name)
+    return module
+
+
+def get_import_path(value):
+    """Returns the shortest dot import path for the given object."""
+    path = value.__module__ + '.' + value.__qualname__
+    if '.' in value.__module__:
+        module_parts = value.__module__.split('.')
+        for num in range(len(module_parts)):
+            module_path = '.'.join(module_parts[:num+1])
+            module = import_module_leaf(module_path)
+            if '.' in value.__qualname__:
+                obj_name, attr = value.__qualname__.rsplit('.', 1)
+                obj = getattr(module, obj_name, None)
+                if getattr(obj, attr, None) is value:
+                    path = module_path + '.' + value.__qualname__
+                    break
+            elif getattr(module, value.__qualname__, None) is value:
+                path = module_path + '.' + value.__qualname__
+                break
+    return path
+
+
+def object_path_serializer(value):
+    try:
+        path = get_import_path(value)
+        reimported = import_object(path)
+        if value is not reimported:
+            raise ValueError
+        return path
+    except Exception as ex:
+        raise ValueError(f'Only possible to serialize an importable object, given {value}: {ex}') from ex
+
+
 lenient_check: ContextVar = ContextVar('lenient_check', default=False)
 
 
@@ -132,14 +230,6 @@ def _lenient_check_context(caller=None):
         lenient_check.reset(t)
 
 
-@contextmanager
-def _suppress_stderr():
-    """A context manager that redirects stderr to devnull."""
-    with open(os.devnull, 'w') as fnull:
-        with redirect_stderr(fnull):
-            yield None
-
-
 @contextmanager
 def change_to_path_dir(path: Optional['Path']):
     """A context manager for running code in the directory of a path."""
