@@ -39,7 +39,7 @@ from jsonargparse.optionals import (
     url_support,
 )
 from jsonargparse.typing import NotEmptyStr, Path_fc, Path_fr, PositiveFloat, PositiveInt
-from jsonargparse.util import _suppress_stderr
+from jsonargparse.util import CaptureParserException, capture_parser, DebugException
 from jsonargparse_tests.base import TempDirTestCase, responses, responses_activate
 
 
@@ -1045,6 +1045,15 @@ class OtherTests(unittest.TestCase):
         self.assertIn('Parser key "val":', err.getvalue())
 
 
+    @unittest.mock.patch.dict(os.environ, {'JSONARGPARSE_DEBUG': ''})
+    def test_debug_usage_and_exit_error_handler(self):
+        parser = ArgumentParser()
+        parser.add_argument('--int', type=int)
+        err = StringIO()
+        with redirect_stderr(err), self.assertRaises(DebugException):
+            parser.parse_args(['--int=invalid'])
+
+
     def test_error_handler_property(self):
         parser = ArgumentParser()
         self.assertEqual(parser.error_handler, usage_and_exit_error_handler)
@@ -1103,5 +1112,27 @@ class OtherTests(unittest.TestCase):
         self.assertEqual(parser1.get_defaults(), parser2.get_defaults())
 
 
+    def test_unrecognized_arguments(self):
+        parser = ArgumentParser()
+        err = StringIO()
+        with redirect_stderr(err):
+            self.assertRaises(SystemExit, lambda: parser.parse_args(['--unrecognized']))
+        self.assertIn('Unrecognized arguments:', err.getvalue())
+
+
+    def test_capture_parser(self):
+        def parse_args(args=[]):
+            parser = ArgumentParser()
+            parser.add_argument('--int', type=int, default=1)
+            return parser.parse_args(args)
+
+        parser = capture_parser(parse_args, ['--int=2'])
+        self.assertIsInstance(parser, ArgumentParser)
+        self.assertEqual(parser.get_defaults(), Namespace(int=1))
+
+        with self.assertRaises(CaptureParserException):
+            capture_parser(lambda: None)
+
+
 if __name__ == '__main__':
     unittest.main(verbosity=2)
